==> gradle-6.1-rc-3-src.zip: gradle-6.1-rc-3/subprojects/language-scala/src/main/java/org/gradle/api/internal/tasks/scala/ZincScalaCompilerFacade.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.scala;

import org.gradle.api.tasks.WorkResult;
import org.gradle.cache.CacheRepository;
import org.gradle.cache.internal.CacheFactory;
import org.gradle.cache.internal.DefaultCacheRepository;
import org.gradle.cache.internal.DefaultCacheScopeMapping;
import org.gradle.initialization.GradleUserHomeDirProvider;
import org.gradle.language.base.internal.compile.Compiler;
import org.gradle.util.GradleVersion;

import javax.inject.Inject;
import java.io.File;
import java.io.Serializable;

public class ZincScalaCompilerFacade implements Compiler<ScalaJavaJointCompileSpec>, Serializable {
    private final CacheRepository cacheRepository;
    private final Iterable<File> scalaClasspath;

    @Inject
    public ZincScalaCompilerFacade(CacheFactory cacheFactory, GradleUserHomeDirProvider gradleUserHomeDirProvider, Iterable<File> scalaClasspath) {
        // TODO: This should be injectable
        DefaultCacheScopeMapping cacheScopeMapping = new DefaultCacheScopeMapping(
                gradleUserHomeDirProvider.getGradleUserHomeDirectory(), null, GradleVersion.current());
        this.cacheRepository = new DefaultCacheRepository(cacheScopeMapping, cacheFactory);
        this.scalaClasspath = scalaClasspath;
    }

    @Override
    public WorkResult execute(ScalaJavaJointCompileSpec spec) {
        return ZincScalaCompilerFactory.getCompiler(cacheRepository, scalaClasspath).execute(spec);
    }
}

==> gradle-6.8-rc-3-src.zip: gradle-6.8-rc-3/subprojects/language-scala/src/main/java/org/gradle/api/internal/tasks/scala/ZincScalaCompilerFacade.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.scala;

import org.gradle.api.tasks.WorkResult;
import org.gradle.cache.CacheRepository;
import org.gradle.cache.internal.CacheFactory;
import org.gradle.cache.internal.DefaultCacheRepository;
import org.gradle.cache.internal.DefaultCacheScopeMapping;
import org.gradle.initialization.GradleUserHomeDirProvider;
import org.gradle.language.base.internal.compile.Compiler;
import org.gradle.util.GradleVersion;

import javax.inject.Inject;
import java.io.Serializable;

public class ZincScalaCompilerFacade implements Compiler<ScalaJavaJointCompileSpec>, Serializable {
    private final CacheRepository cacheRepository;

    private final HashedClasspath scalaClasspath;

    private final boolean leakCompilerClasspath;


    @Inject
    public ZincScalaCompilerFacade(CacheFactory cacheFactory, GradleUserHomeDirProvider gradleUserHomeDirProvider, HashedClasspath scalaClasspath, @Deprecated boolean leakCompilerClasspath) {
        // TODO: This should be injectable
        // TODO: remove leakCompilerClasspath when ScalaLanguagePlugin is removed
        DefaultCacheScopeMapping cacheScopeMapping = new DefaultCacheScopeMapping(
                gradleUserHomeDirProvider.getGradleUserHomeDirectory(), null, GradleVersion.current());
        this.cacheRepository = new DefaultCacheRepository(cacheScopeMapping, cacheFactory);
        this.scalaClasspath = scalaClasspath;
        this.leakCompilerClasspath = leakCompilerClasspath;
    }

    @Override
    public WorkResult execute(ScalaJavaJointCompileSpec spec) {
        return ZincScalaCompilerFactory.getCompiler(cacheRepository, scalaClasspath, leakCompilerClasspath).execute(spec);
    }
}
